# vim: ts=8:sts=8:sw=8:noexpandtab
#
# This file is part of Decoder++
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from dpp.ui.widget.search_field import SearchField
from dpp.ui.widget.shortcut_table import KeyboardShortcutTable
from dpp.ui.widget.spacers import Spacer, VSpacer, HSpacer
from dpp.ui.widget.tab_bar import TabBar
from dpp.ui.widget.icon_label import IconLabel
